pub struct ConstraintDegreeCollector {
pub q_degrees: Vec<usize>,
pub fq_degrees: Vec<Vec<usize>>,
}Expand description
Collects the degree of each constraint in a UAIR by implementing the
ConstraintBuilder trait.
Fields
q_degrees: Vec<usize>fq_degrees: Vec<Vec<usize>>Trait Implementations
Sourceimpl ConstraintBuilder for ConstraintDegreeCollector
impl ConstraintBuilder for ConstraintDegreeCollector
Sourcetype Expr = DegreeCountingSemiring
type Expr = DegreeCountingSemiring
The expressions the constraint builder operates on.
It is opaque from the PoV of an AIR: arithmetic operations on it are
provided by the expression config passed to
Uair::constrain_general alongside the builder.Sourcetype Ideal = ImpossibleIdeal
type Ideal = ImpossibleIdeal
The type of ideals used by the constraint builder.
Sourcetype FqIdeal = ImpossibleIdeal
type FqIdeal = ImpossibleIdeal
Ideals living over $F_{q_i}[X]$ for the prime tuple declared by
the surrounding
UairSignature::primes. A single
ConstraintBuilder shares one runtime type for all primes; the prime
index is passed at the call site via
ConstraintBuilder::assert_in_fq_ideal. Builders that don’t care
about $F_q[X]$-constraints (counters, collectors, etc.) set
this to ImpossibleIdeal.Sourcefn assert_in_ideal(&mut self, expr: Self::Expr, _ideal: &Self::Ideal)
fn assert_in_ideal(&mut self, expr: Self::Expr, _ideal: &Self::Ideal)
Add a constraint saying that
expr belongs to the ideal ideal.Sourcefn assert_zero(&mut self, expr: Self::Expr)
fn assert_zero(&mut self, expr: Self::Expr)
Add a constraint saying that
expr is equal to zero which is
the same as saying that expr belongs to the zero ideal.Sourceimpl Debug for ConstraintDegreeCollector
impl Debug for ConstraintDegreeCollector
Sourceimpl Default for ConstraintDegreeCollector
impl Default for ConstraintDegreeCollector
Sourcefn default() -> ConstraintDegreeCollector
fn default() -> ConstraintDegreeCollector
Returns the “default value” for a type. Read more